@@ -2,6 +2,8 @@ package Exception::Chain;
 use 5.008005;
 use strict;
 use warnings;
+use overload
+    "\"\"" => \&to_string;
 
 use Class::Accessor::Lite (
     ro => [qw/ delivery is_delivery_duplicated duplicated_trace /],
@@ -10,7 +12,7 @@ use Time::Piece qw(localtime);
 use Time::HiRes qw(gettimeofday tv_interval);
 use Data::Dumper;
 
-our $VERSION   = "0.08";
+our $VERSION   = "0.09";
 our $SkipDepth = 0;
 
 # class method
@@ -229,11 +231,17 @@ Exception::Chain is chained exception module
 =head1 METHODS
 
 =head2 throw(%info)
+
 store a following value.
+
 =over
+
 =item tag ($info{tag})
+
 =item message ($info{message})
+
 =item delivery ($info{delivery}). it's stored only once.
+
 =back
 
     throw($e); # Exception::Chain instance or message
@@ -256,28 +264,39 @@ store a following value.
         delivery => HTTP::Response->new( 500, 'internal server error' ),
     )
 
+=head2 rethrow
+
+rethrow exception object.
+
 =head2 to_string
+
 chained log.
 
 =head2 first_message
+
 first message.
 
 =head2 match(@tags)
+
 matching stored tag.
 
 =head2 delivery
+
 delivered object. (or scalar object)
 
 =head2 is_delivery_duplicated
+
 (it's development tool)
 if delivery was duplicated, 1;
 
 =head2 duplicated_trace
+
 (it's development tool)
 description of the occured file and line.
 
 =head1 GLOBAL VARIABLES
-=head2 $Exception::Chain::SkipDepth
+
+$Exception::Chain::SkipDepth
 
 =head1 LICENSE
 
